Learn R Programming

TRSbook (version 1.0.4)

TRSbook-package: Package illustrating the book: The R Software

Description

This package enables one to use some functions used in the book:The R Software, Fundamentals of Programming and Statistical Analysis, Springer, 2014. One can also find the datasets used in the book.

Arguments

Author

Lafaye de Micheaux Pierre <lafaye@unsw.edu.au>, Remy Drouilhet <Remy.Drouilhet@upmf-grenoble.fr>, Liquet Benoit <b.liquet@uq.edu.au>

Details

Package:TheRSoftware
Type:Package
Version:1.0
Date:2014-02-04
License:GPL(>=2.0)
LazyLoad:yes

References

Book: The R Software, Fundamentals of Programming and Statistical Analysis, Springer, 2014