Learn R Programming

TRSbook (version 1.0.4)

arrowaxis: Adding arrows on statistical plots.

Description

This function add an arrow on the extremities of the axes of a plot

Usage

arrowaxis(x = TRUE, y = TRUE)

Value

No return value, called for side effects. The function adds an axis with arrows to the current plot.

Arguments

x

Logical. Default value TRUE indicates an arrow on the x-axis

y

Logical. Default value TRUE indicates an arrow on the y-axis

Author

Lafaye de Micheaux Pierre <lafaye@unsw.edu.au>, Remy Drouilhet <Remy.Drouilhet@upmf-grenoble.fr>, Liquet Benoit <b.liquet@uq.edu.au>

References

Chapter 11 (Descriptive Statistics) from the book: The R Software, Fundamentals of Programming and Statistical Analysis

Examples

Run this code
curve(cos(x),xlim=c(-10,10))
arrowaxis()

Run the code above in your browser using DataLab