Learn R Programming

TRSbook (version 1.0.4)

cor0.test: Test of the correlation coefficient

Description

Test of the correlation coefficient between two quantitative variables

Usage

cor0.test(x, y, rho0 = 0, alternative = c("two.sided", "less", "greater"))

Value

Returns a list:

statistic

Value of the test statistic

p.value

p-value of the test

Arguments

x

numeric vector

y

numeric vector

rho0

numeric indicating the value of the correlation coefficient under the null. Default is rho0 = 0

alternative

Alternative hypothesis for the test. Either two sided ("two.sided"), one sided to the left ("less") or one sided to the right ("greater"). Default is "two.sided".

Author

Lafaye de Micheaux Pierre <lafaye@unsw.edu.au>, Remy Drouilhet <Remy.Drouilhet@upmf-grenoble.fr>, Liquet Benoit <b.liquet@uq.edu.au>

References

Chapter 13 (Confidence Intervals and Hypothesis Testing) from the book: The R Software, Fundamentals of Programming and Statistical Analysis

See Also

Examples

Run this code
data(BMI.CHILD)
attach(BMI.CHILD)
cor0.test(weight,height)
detach(BMI.CHILD)

Run the code above in your browser using DataLab