powered by
This function tries to make a nicer plot than the one given by the plot() function for two quantitative variables
plot()
flashy.plot(x,y,my.factor, family = "Courier",xlab="",ylab="")
A flashy scatter plot
numeric vector
factor
font family for the title. Default is "Courier". Another choice can be, e.g., "HersheyScript"
character. x label
character. y label
Lafaye de Micheaux Pierre <lafaye@unsw.edu.au>, Remy Drouilhet <Remy.Drouilhet@upmf-grenoble.fr>, Liquet Benoit <b.liquet@uq.edu.au>
Chapter 11 (Descriptive Statistics) from the book: The R Software, Fundamentals of Programming and Statistical Analysis
plot
data(NUTRIELDERLY) attach(NUTRIELDERLY) gender <- as.factor(gender) levels(gender) <- c("Male","Female") flashy.plot(weight,height,gender,xlab="Height",ylab="Weight") detach(NUTRIELDERLY)
Run the code above in your browser using DataLab