powered by
This function add an arrow on the extremities of the axes of a plot
arrowaxis(x = TRUE, y = TRUE)
No return value, called for side effects. The function adds an axis with arrows to the current plot.
Logical. Default value TRUE indicates an arrow on the x-axis
TRUE
Logical. Default value TRUE indicates an arrow on the y-axis
Lafaye de Micheaux Pierre <lafaye@unsw.edu.au>, Remy Drouilhet <Remy.Drouilhet@upmf-grenoble.fr>, Liquet Benoit <b.liquet@uq.edu.au>
Chapter 11 (Descriptive Statistics) from the book: The R Software, Fundamentals of Programming and Statistical Analysis
curve(cos(x),xlim=c(-10,10)) arrowaxis()
Run the code above in your browser using DataLab