powered by
To compute the decimal representation of a number written in a binary format
bin2dec(x)
Decimal representation of the number x
x
Numeric. Number in binary format written only with 0s and 1s. See Example below.
Lafaye de Micheaux Pierre <lafaye@unsw.edu.au>, Remy Drouilhet <Remy.Drouilhet@upmf-grenoble.fr>, Liquet Benoit <b.liquet@uq.edu.au>
Chapter 5 (Data Manipulation, Functions) from the book: The R Software, Fundamentals of Programming and Statistical Analysis
bin2dec(1010.101)
Run the code above in your browser using DataLab