powered by
A variant of the pie function
pie
camembert(x, col = NULL, family="Courier")
A pie chart
qualitative variable
vector of characters for the color of each modality
font family for the title. Default is "Courier". Another choice can be, e.g., "HersheyScript"
Lafaye de Micheaux Pierre <lafaye@unsw.edu.au>, Remy Drouilhet <Remy.Drouilhet@upmf-grenoble.fr>, Liquet Benoit <b.liquet@uq.edu.au>
Chapter 11 (Descriptive Statistics) from the book: The R Software, Fundamentals of Programming and Statistical Analysis
data(NUTRIELDERLY) attach(NUTRIELDERLY) require("RColorBrewer") col <- brewer.pal(8,"Pastel2") camembert(fat,col) detach(NUTRIELDERLY)
Run the code above in your browser using DataLab