powered by
To compute the binary representation of a number written in a decimal format
dec2bin(x,prec=52)
Binary representation of the number x
x
Numeric. Number in a decimal format.
Integer. Precision desired.
Lafaye de Micheaux Pierre <lafaye@unsw.edu.au>, Remy Drouilhet <Remy.Drouilhet@upmf-grenoble.fr>, Liquet Benoit <b.liquet@uq.edu.au>
Chapter 5 (Data Manipulation, Functions) from the book: The R Software, Fundamentals of Programming and Statistical Analysis
dec2bin(10.625,3)
Run the code above in your browser using DataLab